@@ -36,6 +36,8 @@
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomeui/gnome-icon-entry.h>
 
+#include <libgnomevfs/gnome-vfs-utils.h>
+
 #include <libgnome/gnome-desktop-item.h>
 #include <libgnomeui/gnome-ditem-edit.h>
 
@@ -674,6 +676,9 @@ setup_translations_list (GnomeDItemEdit *dee)
 					"text", 3, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
 
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
+					      0, GTK_SORT_ASCENDING);
+
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (tree));
 
 	gtk_tree_view_set_headers_clickable (GTK_TREE_VIEW (tree), FALSE);
@@ -1044,6 +1049,19 @@ get_language (void)
 	return NULL;
 }
 
+static void
+ensure_item_localefiled (GnomeDesktopItem *ditem,
+			 const char       *field)
+{
+	const char *localized;
+
+	if (gnome_desktop_item_get_string (ditem, field) == NULL) {
+		localized = gnome_desktop_item_get_localestring (ditem, field);
+		if (localized != NULL)
+			gnome_desktop_item_set_string (ditem, field, localized);
+	}
+}
+
 static void
 gnome_ditem_edit_sync_ditem (GnomeDItemEdit *dee)
 {
@@ -1053,6 +1071,7 @@ gnome_ditem_edit_sync_ditem (GnomeDItemEdit *dee)
 	GtkWidget        *entry;
 	const char       *type;
 	const char       *uri;
+	char             *free_uri;
 	const char       *attr;
 	char             *file;
 	gboolean          ret;
@@ -1073,12 +1092,18 @@ gnome_ditem_edit_sync_ditem (GnomeDItemEdit *dee)
 	gnome_desktop_item_set_string (ditem, GNOME_DESKTOP_ITEM_TYPE, type);
 
 	/* hack really */
-	if (type && !strcmp (type, "Link"))
+	free_uri = NULL;
+	if (type && !strcmp (type, "Link")) {
+		free_uri = gnome_vfs_make_uri_canonical (uri);
+		uri = free_uri;
+
 		attr = GNOME_DESKTOP_ITEM_URL;
-	else
+	} else
 		attr  = GNOME_DESKTOP_ITEM_EXEC;
 
 	gnome_desktop_item_set_string (ditem, attr, uri);
+	if (free_uri)
+		g_free (free_uri);
 
 	gnome_desktop_item_set_string (
 		ditem, GNOME_DESKTOP_ITEM_TRY_EXEC,
@@ -1165,6 +1190,14 @@ gnome_ditem_edit_sync_ditem (GnomeDItemEdit *dee)
 	gnome_desktop_item_set_localestring (
 			ditem, GNOME_DESKTOP_ITEM_COMMENT,
 			gtk_entry_get_text (GTK_ENTRY(dee->_priv->comment_entry)));
+
+	/* Make sure we set the "C" locale strings to the terms we set here.
+	 * This is so that if the user logs into another locale they get their
+	 * own description there rather then empty. It is not the C locale
+	 * however, but the user created this entry herself so it's OK */
+	ensure_item_localefiled (ditem, GNOME_DESKTOP_ITEM_NAME);
+	ensure_item_localefiled (ditem, GNOME_DESKTOP_ITEM_GENERIC_NAME);
+	ensure_item_localefiled (ditem, GNOME_DESKTOP_ITEM_COMMENT);
 			
 	dee->_priv->ui_dirty = FALSE;
 }
@@ -1173,6 +1206,7 @@ gnome_ditem_edit_sync_ditem (GnomeDItemEdit *dee)
  * gnome_ditem_edit_load_uri
  * @dee: #GnomeDItemEdit object to work with
  * @uri: file to load into the editting areas
+ * @error: location to store error, or NULL
  *
  * Description: Load a .desktop file and update the editting areas
  * of the object accordingly.
@@ -1215,8 +1249,6 @@ gnome_ditem_edit_load_uri (GnomeDItemEdit *dee,
  * internally so do not worry about modifying this item later yourself.
  * Note that since the entire item is stored, any hidden fields will be
  * preserved when you later get it with #gnome_ditem_edit_get_ditem.
- *
- * Returns:
  */
 void
 gnome_ditem_edit_set_ditem (GnomeDItemEdit *dee,
@@ -1269,8 +1301,6 @@ gnome_ditem_edit_get_ditem (GnomeDItemEdit *dee)
  *
  * Description: Clear the editting areas.  And unref any
  * stored #GnomeDesktopItem.
- *
- * Returns:
  */
 void
 gnome_ditem_edit_clear (GnomeDItemEdit *dee)
@@ -1459,6 +1489,10 @@ destroy_tooltip (GtkObject *object)
 
 /**
  * set_tooltip
+ * @dee: #GnomeDItemEdit object to work with
+ * @widget: the GtkWidget you wish to associate the tip with.
+ * @description: a string containing the tip itself.
+ *
  * Description : Set @description as the tooltip for the @widget.
  *		 Creates the GtkTooltips structure if not already present.
  */
